Requirements
============

Django
------
Modern Django versions are supported. Currently this list includes Django 2.*, and 3.2

Django REST Framework
------
Modern Django REST Framework versions are supported. Currently this list includes Django REST Framework 3.10.*

Simple JWT
------
Modern Simple JWT versions are supported. Currently this list includes Simple JWT 4.3.*

Python
------
The following Python versions are supported: 3.5, 3.6, 3.7 and 3.8 with a
limit to what Django itself supports. As support for older Django versions is
dropped, the minimum version might be raised. See also `What Python version can
I use with Django?`_.


.. _What Python version can I use with Django?:
   https://docs.djangoproject.com/en/stable/faq/install/#what-python-version-can-i-use-with-django
